@@ -25,13 +25,12 @@ THE SOFTWARE.
 #include "pipeline/node.h"
 #include "parameters/parameter_factory.h"
 #include "parameters/parameter_vx.h"
-#include "rocal_api_types.h"
 
 class PreemphasisFilterNode : public Node {
     public:
         PreemphasisFilterNode(const std::vector<Tensor *> &inputs, const std::vector<Tensor *> &outputs);
         PreemphasisFilterNode() = delete;
-        void init(FloatParam *preemph_coeff, RocalAudioBorderType preemph_border);
+        void init(FloatParam *preemph_coeff, AudioBorderType preemph_border);
 
     protected:
         void create_node() override;
@@ -40,5 +39,5 @@ class PreemphasisFilterNode : public Node {
     private:
         ParameterVX<float> _preemph_coeff;
         constexpr static float PREEMPH_COEFF_RANGE[2] = {0.97, 0.97};
-        RocalAudioBorderType _preemph_border;
+        AudioBorderType _preemph_border;
 };
