@@ -22,14 +22,13 @@ THE SOFTWARE.
 
 #pragma once
 #include "pipeline/node.h"
-#include "rocal_api_types.h"
 
 class ResizeNode : public Node {
 public:
     ResizeNode(const std::vector<Tensor *> &inputs, const std::vector<Tensor *> &outputs);
     ResizeNode() = delete;
-    void init(unsigned dest_width, unsigned dest_height, RocalResizeScalingMode scaling_mode,
-              const std::vector<unsigned>& max_size, RocalResizeInterpolationType interpolation_type);
+    void init(unsigned dest_width, unsigned dest_height, ResizeScalingMode scaling_mode,
+              const std::vector<unsigned>& max_size, ResizeInterpolationType interpolation_type);
     void adjust_out_roi_size();
 protected:
     void create_node() override;
@@ -37,7 +36,7 @@ protected:
 private:
     vx_array  _dst_roi_width , _dst_roi_height;
     int _interpolation_type;
-    RocalResizeScalingMode _scaling_mode;
+    ResizeScalingMode _scaling_mode;
     unsigned _src_width, _src_height, _dst_width, _dst_height, _out_width, _out_height;
     unsigned _max_width = 0, _max_height = 0;
     std::vector<unsigned> _dst_roi_width_vec, _dst_roi_height_vec;
