@@ -29,8 +29,8 @@ class ResizeMirrorNormalizeNode : public Node {
    public:
     ResizeMirrorNormalizeNode(const std::vector<Tensor *> &inputs, const std::vector<Tensor *> &outputs);
     ResizeMirrorNormalizeNode() = delete;
-    void init(unsigned dest_width, unsigned dest_height, RocalResizeScalingMode scaling_mode, std::vector<unsigned> max_size,
-              RocalResizeInterpolationType interpolation_type, std::vector<float> &mean, std::vector<float> &std_dev, IntParam *mirror);
+    void init(unsigned dest_width, unsigned dest_height, ResizeScalingMode scaling_mode, std::vector<unsigned> max_size,
+              ResizeInterpolationType interpolation_type, std::vector<float> &mean, std::vector<float> &std_dev, IntParam *mirror);
     void adjust_out_roi_size();
     vx_array get_mirror() { return _mirror.default_array(); }
 
@@ -44,7 +44,7 @@ class ResizeMirrorNormalizeNode : public Node {
     int _interpolation_type;
     ParameterVX<int> _mirror;
     constexpr static int _mirror_range[2] = {0, 1};
-    RocalResizeScalingMode _scaling_mode;
+    ResizeScalingMode _scaling_mode;
     unsigned _src_width, _src_height, _dst_width, _dst_height, _out_width, _out_height;
     unsigned _max_width = 0, _max_height = 0;
     std::vector<unsigned> _dst_roi_width_vec, _dst_roi_height_vec;
