@@ -25,14 +25,13 @@ THE SOFTWARE.
 #include "pipeline/node.h"
 #include "parameters/parameter_factory.h"
 #include "parameters/parameter_vx.h"
-#include "rocal_api_types.h"
 
 class RotateNode : public Node {
    public:
     RotateNode(const std::vector<Tensor *> &inputs, const std::vector<Tensor *> &outputs);
     RotateNode() = delete;
-    void init(float angle, RocalResizeInterpolationType interpolation_type = ROCAL_LINEAR_INTERPOLATION);
-    void init(FloatParam *angle_param, RocalResizeInterpolationType interpolation_type = ROCAL_LINEAR_INTERPOLATION);
+    void init(float angle, ResizeInterpolationType interpolation_type = ResizeInterpolationType::LINEAR);
+    void init(FloatParam *angle_param, ResizeInterpolationType interpolation_type = ResizeInterpolationType::LINEAR);
     unsigned int get_dst_width() { return _outputs[0]->info().max_shape()[0]; }
     unsigned int get_dst_height() { return _outputs[0]->info().max_shape()[1]; }
     vx_array get_angle() { return _angle.default_array(); }
