@@ -25,13 +25,12 @@ THE SOFTWARE.
 #include "pipeline/node.h"
 #include "parameters/parameter_factory.h"
 #include "parameters/parameter_vx.h"
-#include "rocal_api_types.h"
 
 class SliceNode : public Node {
    public:
     SliceNode(const std::vector<Tensor *> &inputs, const std::vector<Tensor *> &outputs);
     SliceNode() = delete;
-    void init(Tensor *anchor_param, Tensor *shape_param, std::vector<float> &fill_values_param, RocalOutOfBoundsPolicy policy);
+    void init(Tensor *anchor_param, Tensor *shape_param, std::vector<float> &fill_values_param, OutOfBoundsPolicy policy);
 
    protected:
     void create_node() override;
@@ -40,5 +39,5 @@ class SliceNode : public Node {
    private:
     Tensor *_anchor, *_shape;
     std::vector<float> _fill_values, _fill_values_vec;
-    RocalOutOfBoundsPolicy _policy = RocalOutOfBoundsPolicy::ROCAL_ERROR;
+    OutOfBoundsPolicy _policy = OutOfBoundsPolicy::ERROR;
 };
