@@ -83,8 +83,8 @@ void ResizeNode::update_node() {
     _dst_roi_height_vec.clear();
 }
 
-void ResizeNode::init(unsigned dest_width, unsigned dest_height, RocalResizeScalingMode scaling_mode,
-                      const std::vector<unsigned> &max_size, RocalResizeInterpolationType interpolation_type) {
+void ResizeNode::init(unsigned dest_width, unsigned dest_height, ResizeScalingMode scaling_mode,
+                      const std::vector<unsigned> &max_size, ResizeInterpolationType interpolation_type) {
     _interpolation_type = (int)interpolation_type;
     _scaling_mode = scaling_mode;
     _out_width = dest_width;
@@ -98,7 +98,7 @@ void ResizeNode::init(unsigned dest_width, unsigned dest_height, RocalResizeScal
 void ResizeNode::adjust_out_roi_size() {
     bool has_max_size = (_max_width | _max_height) > 0;
 
-    if (_scaling_mode == RocalResizeScalingMode::ROCAL_SCALING_MODE_STRETCH) {
+    if (_scaling_mode == ResizeScalingMode::STRETCH) {
         if (!_dst_width) _dst_width = _src_width;
         if (!_dst_height) _dst_height = _src_height;
 
@@ -106,10 +106,10 @@ void ResizeNode::adjust_out_roi_size() {
             if (_max_width) _dst_width = std::min(_dst_width, _max_width);
             if (_max_height) _dst_height = std::min(_dst_height, _max_height);
         }
-    } else if (_scaling_mode == RocalResizeScalingMode::ROCAL_SCALING_MODE_DEFAULT) {
-        if ((!_dst_width) & _dst_height) {  // Only height is passed
+    } else if (_scaling_mode == ResizeScalingMode::DEFAULT) {
+        if ((!_dst_width) && _dst_height) {  // Only height is passed
             _dst_width = std::lround(_src_width * (static_cast<float>(_dst_height) / _src_height));
-        } else if ((!_dst_height) & _dst_width) {  // Only width is passed
+        } else if ((!_dst_height) && _dst_width) {  // Only width is passed
             _dst_height = std::lround(_src_height * (static_cast<float>(_dst_width) / _src_width));
         }
 
@@ -121,9 +121,9 @@ void ResizeNode::adjust_out_roi_size() {
         float scale = 1.0f;
         float scale_w = static_cast<float>(_dst_width) / _src_width;
         float scale_h = static_cast<float>(_dst_height) / _src_height;
-        if (_scaling_mode == RocalResizeScalingMode::ROCAL_SCALING_MODE_NOT_SMALLER) {
+        if (_scaling_mode == ResizeScalingMode::NOT_SMALLER) {
             scale = std::max(scale_w, scale_h);
-        } else if (_scaling_mode == RocalResizeScalingMode::ROCAL_SCALING_MODE_NOT_LARGER) {
+        } else if (_scaling_mode == ResizeScalingMode::NOT_LARGER) {
             scale = (scale_w > 0 && scale_h > 0) ? std::min(scale_w, scale_h) : ((scale_w > 0) ? scale_w : scale_h);
         }
 
