@@ -19,9 +19,6 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
-#if ENABLE_OPENCL
-#include <CL/cl.h>
-#endif
 #include <omp.h>
 #include <vx_ext_amd.h>
 #include <VX/vx_types.h>
@@ -30,7 +27,6 @@ THE SOFTWARE.
 #include <half/half.hpp>
 #include "pipeline/master_graph.h"
 #include "parameters/parameter_factory.h"
-#include "device/ocl_setup.h"
 #include "pipeline/log.h"
 #include "meta_data/meta_data_reader_factory.h"
 #include "meta_data/meta_data_graph_factory.h"
@@ -107,8 +103,6 @@ MasterGraph::MasterGraph(size_t batch_size, RocalAffinity affinity, size_t cpu_t
                                                                                                                                                                                      _user_batch_size(batch_size),
 #if ENABLE_HIP
                                                                                                                                                                                      _mem_type((_affinity == RocalAffinity::GPU) ? RocalMemType::HIP : RocalMemType::HOST),
-#elif ENABLE_OPENCL
-                                                                                                                                                                                     _mem_type((_affinity == RocalAffinity::GPU) ? RocalMemType::OCL : RocalMemType::HOST),
 #else
                                                                                                                                                                                      _mem_type(RocalMemType::HOST),
 #endif
@@ -130,17 +124,7 @@ MasterGraph::MasterGraph(size_t batch_size, RocalAffinity affinity, size_t cpu_t
             THROW("vxCreateContext failed" + TOSTR(status))
 
         if (affinity == RocalAffinity::GPU) {
-#if ENABLE_OPENCL
-            if (_mem_type == RocalMemType::OCL) {
-                cl_context _cl_context = nullptr;
-                cl_device_id _cl_device_id = nullptr;
-                get_device_and_context(gpu_id, &_cl_context, &_cl_device_id, CL_DEVICE_TYPE_GPU);
-                if ((status = vxSetContextAttribute(_context,
-                                                    VX_CONTEXT_ATTRIBUTE_AMD_OPENCL_CONTEXT,
-                                                    &_cl_context, sizeof(cl_context)) != VX_SUCCESS))
-                    THROW("vxSetContextAttribute for CL_CONTEXT failed " + TOSTR(status))
-            }
-#elif ENABLE_HIP
+#if ENABLE_HIP
             if (_mem_type == RocalMemType::HIP) {
                 hipError_t err = hipInit(0);
                 if (err != hipSuccess) {
@@ -180,8 +164,6 @@ MasterGraph::MasterGraph(size_t batch_size, RocalAffinity affinity, size_t cpu_t
         if (_affinity == RocalAffinity::GPU) {
 #if ENABLE_HIP
             _device.init_hip(_context);
-#elif ENABLE_OPENCL
-            _device.init_ocl(_context);
 #endif
         }
         ParameterFactory::instance()->set_seed(0);  // Setting default seed for ParameterFactory instance. User can set the seed manually by calling rocalSetSeed(seed_value)
@@ -285,7 +267,7 @@ MasterGraph::build() {
     if (_internal_tensor_list.empty())
         THROW("No output tensors are there, cannot create the pipeline")
 
-#if ENABLE_HIP || ENABLE_OPENCL
+#if ENABLE_HIP
     _ring_buffer.init(_mem_type, (void *)_device.resources(), _internal_tensor_list.data_size(), _internal_tensor_list.roi_size());
 #else
     _ring_buffer.init(_mem_type, nullptr, _internal_tensor_list.data_size(), _internal_tensor_list.roi_size());
@@ -366,9 +348,7 @@ void MasterGraph::release() {
         loader_module->shut_down();
     // release output buffer if allocated
     if (_output_tensor_buffer != nullptr) {
-#if ENABLE_OPENCL
-        clReleaseMemObject((cl_mem)_output_tensor_buffer);
-#elif ENABLE_HIP
+#if ENABLE_HIP
         hipError_t err = hipFree(_output_tensor_buffer);
         if (err != hipSuccess) {
             THROW("MasterGraph::deallocate_output_tensor  hipFree failed " + TOSTR(err))
@@ -541,76 +521,7 @@ MasterGraph::to_tensor(void *out_ptr, RocalTensorlayout format, float multiplier
         max_roi_width = w;
     }
 
-#if ENABLE_OPENCL
-    if (output_tensor_info.mem_type() == RocalMemType::OCL) {
-        if (output_data_type == RocalTensorDataType::FP16)
-            THROW("FP16 tensor output for GPU affinity is not implemented")
-        // OCL device memory
-        cl_int status, ret;
-
-        size_t global_work_size = output_tensor_info.data_size();  // Sample size
-        size_t local_work_size = 256;
-
-        // TODO: Use the runKernel function instead
-
-        auto kernel_name = (format == RocalTensorlayout::NHWC) ? "copyInt8ToNHWC" : "copyInt8ToNCHW";
-        cl_kernel kernel = _device["utility"][kernel_name];
-        auto queue = _device.resources()->cmd_queue;
-        unsigned dest_buf_offset = 0;
-        auto output_buffers = _ring_buffer.get_read_buffers().first;
-
-        if (_output_tensor_buffer == nullptr) {
-            size_t size = output_tensor_info.data_size() * sizeof(cl_float);
-            cl_mem clImgFloat = clCreateBuffer(_device.resources()->context,
-                                               CL_MEM_READ_WRITE,
-                                               size,
-                                               nullptr, &ret);
-            if (!clImgFloat || ret != CL_SUCCESS)
-                THROW("clCreateBuffer of size " + TOSTR(size) + " failed " + TOSTR(ret))
-
-            _output_tensor_buffer = clImgFloat;
-        }
-
-        for (auto &&out_tensor : output_buffers) {
-            int argIdx = 0;
-            unsigned reverse_chnl = reverse_channels ? 1 : 0;
-            auto img_buffer = out_tensor;
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_mem), (void *)&(img_buffer)))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_mem), (void *)&_output_tensor_buffer))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_uint), (void *)&dest_buf_offset))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_uint), (void *)&w))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_uint), (void *)&h))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_uint), (void *)&c))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&multiplier0))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&multiplier1))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&multiplier2))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&offset0))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&offset1))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_float), (void *)&offset2))
-            CHECK_CL_CALL_RET(clSetKernelArg(kernel, argIdx++, sizeof(cl_uint), (void *)&reverse_chnl))
-
-            if ((status = clEnqueueNDRangeKernel(queue,
-                                                 kernel,
-                                                 1,
-                                                 nullptr,
-                                                 &global_work_size,
-                                                 &local_work_size,
-                                                 0, nullptr, nullptr)) != CL_SUCCESS)
-                THROW("clEnqueueNDRangeKernel failed on kernel " + STR(kernel_name) + " error " + TOSTR(status))
-            dest_buf_offset += single_output_tensor_size;
-        }
-
-        int read_size = single_output_tensor_size * _output_tensor_list.size() * sizeof(cl_float);
-        if ((status = clEnqueueReadBuffer(queue,
-                                          (cl_mem)_output_tensor_buffer,
-                                          CL_TRUE,
-                                          0,
-                                          read_size,
-                                          out_ptr,
-                                          0, nullptr, nullptr)) != CL_SUCCESS)
-            THROW("clEnqueueReadBuffer failed: " + TOSTR(status))
-    }
-#elif ENABLE_HIP
+#if ENABLE_HIP
     if (output_tensor_info.mem_type() == RocalMemType::HIP) {
         unsigned int fp16 = (output_data_type == RocalTensorDataType::FP16);
 
@@ -872,30 +783,7 @@ MasterGraph::copy_output(unsigned char *out_ptr, size_t out_size_in_bytes) {
 
     _convert_time.start();
 
-#if ENABLE_OPENCL
-    if (output_tensor_info.mem_type() == RocalMemType::OCL) {
-        size_t dest_buf_offset = 0;
-        // NOTE: the CL_TRUE flag is only used on the last buffer read
-        //  to avoid unnecessary sequence of synchronizations
-
-        // get_read_buffers() calls block_if_empty() internally and blocks if buffers are empty until a new batch is processed
-        auto output_buffers = _ring_buffer.get_read_buffers().first;
-        auto out_image_idx = output_buffers.size();
-        for (auto &&output_handle : output_buffers) {
-            bool sync_flag = (--out_image_idx == 0) ? CL_TRUE : CL_FALSE;
-            cl_int status;
-            if ((status = clEnqueueReadBuffer(_device.resources()->cmd_queue,
-                                              (cl_mem)output_handle,
-                                              sync_flag ? (CL_TRUE) : CL_FALSE,
-                                              0,
-                                              size,
-                                              out_ptr + dest_buf_offset,
-                                              0, nullptr, nullptr)) != CL_SUCCESS)
-                THROW("clEnqueueReadBuffer failed: " + TOSTR(status))
-            dest_buf_offset += size;
-        }
-    } else {
-#elif ENABLE_HIP
+#if ENABLE_HIP
     if (output_tensor_info.mem_type() == RocalMemType::HIP) {
         // NOTE: the CL_TRUE flag is only used on the last buffer read call,
         //  to avoid unnecessary sequence of synchronizations
@@ -919,7 +807,7 @@ MasterGraph::copy_output(unsigned char *out_ptr, size_t out_size_in_bytes) {
         // get_read_buffer is blocking if _ring_buffer is empty, and blocks this thread till internal processing thread process a new batch and store in the _ring_buffer
         auto output_buffer = _ring_buffer.get_read_buffers().first[0];
         memcpy(out_ptr, output_buffer, size);
-#if ENABLE_OPENCL || ENABLE_HIP
+#if ENABLE_HIP
     }
 #endif
     _convert_time.end();
